@@ -9,14 +9,17 @@ else:
     ModuleNotFoundError = ImportError
 
 try:
-    import xlsxreader
+
+    from xlsxreader import readxlsx
+    print('what the fuck?!')
 
 except ModuleNotFoundError:
     sys.path.append('..')
-    import  xlsxreader
+    import xlsxreader
+    print('I am lost')
 
 if 'test' in os.listdir('.'):
     os.chdir('./test')
-
-test_file = xlsxreader.readxlsx("testbook1.xlsx")
+print('whats')
+test_file = xlsxreader.readxlsx('testboo1.xlsx')
 print(str(test_file.read(), encoding="utf-8"))
